--|  
--| Filename        : $Source: /home/ACDE/ACDE/Source/RCS/contents_element.ads,v $
--| Description     : Contents specification
--| Author          : Michael Erdmann
--| Created On      : 25.3.1999
--| Last Modified By: $Author: ACDE $
--| Last Modified On: $Date: 2000/01/21 17:18:23 $
--| Status          : $State: Released $
--| Version         : $Revision: 1.1 $
--|
--|
--| Functional Description
--| ======================
--| A compilation unit consists of several components. The contents
--| information for such a unit is stored in a list of contents
--| elements. 
--|
--| Component Data
--| ============== 
--| There are no attribute methods available. All components
--| are directly visible in order to make the code simple. This
--| is acceptable because it is not planed to reuse this 
--| component.
--|
--| What        : Contents_Type := Method;
--|     Specifies the type of component:
--| 
--|        Method       - Procedure / function
--|        Package_Unit - A package
--|
--| Name        : Unbounded_String := Null_Unbounded_String;
--|     Name of the component i.e. procedure name.
--|
--| Arguments   : Unbounded_String := Null_Unbounded_String;
--|     A string which contains the arguments in case of 
--|     Methods.
--|
--| Returns     : Unbounded_String := Null_Unbounded_String; 
--|     Return type in case of Methods.
--|
--| Comments    : Text_Array_Access := null;
--|     All important comments found so far (all types)
--|
--| Libraries   : Text_Array_Access := null;
--|     Used packages in case of Package_Unit.
--|
--| Operations on the component data
--| ================================
--| None
--|
--| Extension
--| =========
--| None
--|
--| Restrictions
--| ============
--| Tasking: no
--| This package is not intended for reuse.
--|
--| History
--| =======
--| $Log: contents_element.ads,v $
--| Revision 1.1  2000/01/21 17:18:23  ACDE
--| Release Version test_1_0
--|
--| Revision 1.4  2000/01/16 16:06:17  ACDE
--| Release Version V8_1test
--|
--| Revision 1.3  1999/12/30 09:42:09  ACDE
--| HTML formatting code moved into docgen.adb
--|
--| Revision 1.2  1999/12/30 08:51:18  ACDE
--| first test completed
--|
--| Revision 1.1  1999/12/29 12:01:41  ACDE
--| No comments
--|
with Ada.Strings.Unbounded;	use Ada.Strings.Unbounded;

with Interface.List_Element;    use Interface;
use  Interface;

with Simple_List_Element;
with Text_Block;		use Text_Block;
with List;			use List;

package Contents_Element is
   
   ---=====================================================================---
   ---===             C O M P O N E N T   I N T E R F A C E             ===---
   ---=====================================================================---
   type Contents_Type is ( Method, Class_Or_Type, Package_Unit );

   type Contents is record
         What        : Contents_Type := Method;
         Name        : Unbounded_String := Null_Unbounded_String;
	 Arguments   : Unbounded_String := Null_Unbounded_String;
	 Returns     : Unbounded_String := Null_Unbounded_String; 
	 Comments    : Text_Array_Access := null;
	 Libraries   : Text_Array_Access := null;
	 Is_Abstract : Boolean := False;
      end record;

   package Pkg is new Simple_List_Element( Item_Type => Contents );
   use Pkg;

   type Object is new Pkg.Object with null record;

   ---=====================================================================---
   ---===                  A T T R I B U T E S                       ===---
   ---=====================================================================---
   
   ---=====================================================================---
   ---===                     M E T H O D S                             ===---
   ---=====================================================================---

   ---------------------------------------------------------------------------
   --| Description    :
   --|    This function creates an instance of the list element which 
   --|    contains the Contents information.
   --| Preconditions  :
   --|    None
   --| Postconditions :
   --|    None
   --| Exceptions     :
   --|    None
   --| Note           :
   --|    None
   ---------------------------------------------------------------------------
   function Construct( item : in Contents ) return List_Element.Handle;

   ---------------------------------------------------------------------------
   --| Description    :
   --|    This prcoedure returns the value of the list element.
   --| Preconditions  :
   --|    List has to be initialized, and the list has to contain
   --|    contents list elements.
   --| Postconditions :
   --| Exceptions     :
   --| Note           :
   ---------------------------------------------------------------------------
   function Value( item : in List_Element.Handle ) return Contents;

   ---=====================================================================---
   ---===                   E X T E N S I O N                           ===---
   ---=====================================================================---

   ---=====================================================================---
 
end Contents_Element;


