--|  
--| Filename        : $Source: /home/ACDE/ACDE/Source/RCS/dbs-project.ads,v $
--| Description     : ACDE base object
--| Author          : Michael Erdmann
--| Created On      : 4.1.2000
--| Last Modified By: $Author: ACDE $
--| Last Modified On: $Date: 2000/01/21 17:18:23 $
--| Status          : $State: Released $
--| Version         : $Revision: 1.1 $
--|
--| Functional Description
--| ======================
--| This object hide all the ACCE parameters taken from several
--| tables in the data base
--|
--| Component Data
--| ==============
--|
--|
--| Class Data
--| ==========
--|
--| Operations on the component/class data
--| ======================================
--|
--| Store   	      - Store an instance in the data base
--| Load              - Load an instance from the data base
--| Delete	      - Not supported
--| 
--|
--| Extension
--| =========
--|
--| Restrictions
--| ============
--| Tasking: yes/no
--| Y2K    :
--|
--|
--| History
--| =======
--| $Log: dbs-project.ads,v $
--|
--|
with Ada.Strings.Unbounded; use Ada.Strings.Unbounded;
with Ada.Calendar;          use Ada.Calendar;

with ASCL.Debugging_Support;
with ASCL.DB;
use  ASCL;

with DBS.Element;   

package DBS.ACDE is
   
   ---=====================================================================---
   ---===             C O M P O N E N T   I N T E R F A C E             ===---
   ---=====================================================================---
   type Object is new DBS.Element.Object with private;
   type Handle is access Object'Class;

   procedure Initialize( this  : in out Object;
                         debug : in Debugging_Support.Handle := null);
   procedure Finalize( this : in out Object );

   ---=====================================================================---
   ---===                  A T T R I B U T E S                          ===---
   ---=====================================================================---

   ---=====================================================================---
   ---===                     M E T H O D S                             ===---
   ---=====================================================================---

   ---------------------------------------------------------------------------
   --| Description    :
   --|   The methods check whether an object exists or not.
   --| Preconditions  :
   --|   1. Object Initialized.
   --|   2. Object is assigned to a data base
   --|
   --| Postconditions :
   --|   Results true if the object exists, else it returns false.
   --| Exceptions     :
   --|   None
   --| Note           :
   ---------------------------------------------------------------------------

   --|=====================================================================---
   --|===           EXTENSIONS REQUIERED BY DBELEMENT CLASS. 		===---
   --|===       WARNING: THESE METHODS ARE NOT FOR PUBLIC USEAGE	===---
   --|=====================================================================---


   --|------------------------------------------------------------------------
   --| Description    :
   --|   This procedure loads the information for a certain project 
   --|   from the data base.
   --|   The procedure returns true if every thing worked correctly.
   --|
   --|   This procedure is required by the abstract class dbelement.
   --| Preconditions  :
   --|   1. Object Initialized.
   --|   2. Object is assigned to a data base
   --|   3. Project_Name set
   --|
   --| Postconditions :
   --|   project data copied from the data base into the attributes
   --| Exceptions     :
   --|   None
   --| Note           :
   ---------------------------------------------------------------------------
   function Load_Query( this : in Object ) return Boolean;

   ---------------------------------------------------------------------------
   --| Description    :
   --|   Store the object data in the data base.
   --|   This method is required by the abstract class dbelement
   --| Preconditions  :
   --|   1. Object is initialized
   --|   2. Object is assigned to a data base
   --|   3. At least the login_name attribute is set.
   --| Postconditions :
   --|   Project data is stored in the data base
   --| Exceptions     :
   --| Note           :
   ---------------------------------------------------------------------------
   function Store_Query( this : in Object ) return Boolean;

   ---------------------------------------------------------------------------
   --| Description    :
   --|   Delete the data behind a user object from the database
   --| Preconditions  :
   --|   1. Object is initialized
   --|   2. Object is assigned to a data base
   --|   3. At least the project_name attribute is set.
   --| Postconditions :
   --|   Item delete
   --| Exceptions     :
   --| Note           :
   ---------------------------------------------------------------------------
   function Delete_Query( this : in Object ) return Boolean;

   ---=====================================================================---
private
   type Object_Data;
   type Object_Data_Access is access Object_Data;

   type Object is new DBS.Element.Object with record
         data : Object_Data_Access := null;
      end record; 

end DBS.ACDE;






