--|  
--| Filename        : $Source: /home/ACDE/ACDE/Source/RCS/dbs-project.ads,v $
--| Description     : project class
--| Author          : Michael Erdmann
--| Created On      : 4.1.2000
--| Last Modified By: $Author: ACDE $
--| Last Modified On: $Date: 2000/01/21 17:18:23 $
--| Status          : $State: Released $
--| Version         : $Revision: 1.1 $
--|
--| Functional Description
--| ======================
--|
--| Component Data
--| ==============
--|
--| Name
--| Owner  -  Login name of an ACDE User
--| Creation_Date
--| Modify_Date	    
--|
--| Class Data
--| ==========
--|
--| Operations on the component/class data
--| ======================================
--|
--| Store   	      - Store an instance in the data base
--| Load              - Load an instance from the data base
--| Delete
--| 
--| All_Projects      - Returns the list of all users
--| Get		      - Get the next user from the list 
--|
--| Extension
--| =========
--|
--| Restrictions
--| ============
--| Tasking: yes/no
--| Y2K    :
--|
--|
--| History
--| =======
--| $Log: dbs-project.ads,v $
--| Revision 1.1  2000/01/21 17:18:23  ACDE
--| Release Version test_1_0
--|
--|
with Ada.Strings.Unbounded; use Ada.Strings.Unbounded;
with Ada.Calendar;          use Ada.Calendar;

with ASCL.Debugging_Support;
with ASCL.DB;
use  ASCL;

with DBS.Element;   
with List;	

package DBS.Project is
   
   ---=====================================================================---
   ---===             C O M P O N E N T   I N T E R F A C E             ===---
   ---=====================================================================---
   type Object is new DBS.Element.Object with private;
   type Handle is access Object'Class;

   procedure Initialize( this  : in out Object;
                         debug : in Debugging_Support.Handle := null);
   procedure Finalize( this : in out Object );

   procedure Initialize( dBase : DB.Object;
   			 debug : Debugging_Support.Handle := null );

   ---=====================================================================---
   ---===                  A T T R I B U T E S                          ===---
   ---=====================================================================---
   procedure Name( this : in out Object; name : in Unbounded_String );
   procedure Owner( this : in out Object; name : in Unbounded_String );
   procedure Creation_Date( this : in out Object; atTime : in Time );
   procedure Modification_Date( this : in out Object; atTime : in Time );

   function Name( this : in Object ) return String;
   function Creation_Date( this : in Object ) return Time;
   function Modification_Date( this : in Object ) return Time;
   function Owner( this : in Object ) return String;

   ---=====================================================================---
   ---===                     M E T H O D S                             ===---
   ---=====================================================================---

   ---------------------------------------------------------------------------
   --| Description    :
   --|   The methods check whether an object exists or not.
   --| Preconditions  :
   --|   1. Object Initialized.
   --|   2. Object is assigned to a data base
   --|
   --| Postconditions :
   --|   Results true if the object exists, else it returns false.
   --| Exceptions     :
   --|   None
   --| Note           :
   ---------------------------------------------------------------------------
   function Exists( this : in Object; name : in String ) return Boolean;

   ---=====================================================================---
   ---===                   C L A S S   M E T H O D S			===---
   ---=====================================================================---

   ---------------------------------------------------------------------------
   --| Description    :
   --|    Generate a list of all project in the system
   --| Preconditions  :
   --|    1. Package has to be initialized 
   --| Postconditions :
   --|    List contains all users in the system
   --| Exceptions     :
   --| Note           :
   --|    If the list is not needed any more it should be finalized by
   --|    the finalize method from the List package.
   ---------------------------------------------------------------------------
   function All_Projects return List.Object;

   ---------------------------------------------------------------------------
   --| Description    :
   --|    Get the next entry in the list of all projects in the system as
   --|    a string.  
   --|    If the end of the list is reached, an empty string is returned. 
   --| Preconditions  :
   --|    1. Package has to be initialized 
   --|    2. List has to be returned by the All_Users method.
   --| Postconditions :
   --|    Read pointer is set to the next project name.   
   --| Exceptions     :
   --| Note           :
   ---------------------------------------------------------------------------
   function Get( users : List.Object; start : in Boolean := False )
                                                             return String;

   --|=====================================================================---
   --|===           EXTENSIONS REQUIERED BY DBELEMENT CLASS. 		===---
   --|===       WARNING: THESE METHODS ARE NOT FOR PUBLIC USEAGE	===---
   --|=====================================================================---


   --|------------------------------------------------------------------------
   --| Description    :
   --|   This procedure loads the information for a certain project 
   --|   from the data base.
   --|   The procedure returns true if every thing worked correctly.
   --|
   --|   This procedure is required by the abstract class dbelement.
   --| Preconditions  :
   --|   1. Object Initialized.
   --|   2. Object is assigned to a data base
   --|   3. Project_Name set
   --|
   --| Postconditions :
   --|   project data copied from the data base into the attributes
   --| Exceptions     :
   --|   None
   --| Note           :
   ---------------------------------------------------------------------------
   function Load_Query( this : in Object ) return Boolean;

   ---------------------------------------------------------------------------
   --| Description    :
   --|   Store the object data in the data base.
   --|   This method is required by the abstract class dbelement
   --| Preconditions  :
   --|   1. Object is initialized
   --|   2. Object is assigned to a data base
   --|   3. At least the login_name attribute is set.
   --| Postconditions :
   --|   Project data is stored in the data base
   --| Exceptions     :
   --| Note           :
   ---------------------------------------------------------------------------
   function Store_Query( this : in Object ) return Boolean;

   ---------------------------------------------------------------------------
   --| Description    :
   --|   Delete the data behind a user object from the database
   --| Preconditions  :
   --|   1. Object is initialized
   --|   2. Object is assigned to a data base
   --|   3. At least the project_name attribute is set.
   --| Postconditions :
   --|   Item delete
   --| Exceptions     :
   --| Note           :
   ---------------------------------------------------------------------------
   function Delete_Query( this : in Object ) return Boolean;

   ---=====================================================================---
private
   type Object_Data;
   type Object_Data_Access is access Object_Data;

   type Object is new DBS.Element.Object with record
         data : Object_Data_Access := null;
      end record; 

end DBS.Project;






