--|
--| Filename        : $Source: /home/ACDE/ACDE/Source/RCS/dbs-sql.adb,v $
--| Description     : sql helper package
--| Author          : Michael Erdmann
--| Created On      : 25.3.1999
--| Last Modified By: $Author: ACDE $
--| Last Modified On: $Date: 2000/01/21 17:18:23 $
--| Status          : $State: Released $
--| Version         : $Revision: 1.1 $
--|
--| Functional Description
--| ======================
--| This package builds the basic sql query strings.
--|
--|
--| Restrictions
--| ============
--| None
--|
--| References
--| ==========
--|
--|
--| History
--| =======
--| $Log: dbs-sql.adb,v $
--| Revision 1.1  2000/01/21 17:18:23  ACDE
--| Release Version test_1_0
--|
--|
--|

--* Ada
with Ada.Exceptions;               use Ada.Exceptions;
with Ada.Strings.Unbounded;        use Ada.Strings.Unbounded;

with ASCL.Debugging_Support;  	   use ASCL.Debugging_Support;
use  ASCL;

package body DBS.SQL is

   Version : constant String := "$Id: dbs-sql.adb,v 1.1 2000/01/21 17:18:23 ACDE Released ACDE $";
   Module  : constant String := "sql.adb";

   ---=====================================================================---
   ---===             C L A S S    D A T A / M E T H O D S              ===---
   ---=====================================================================---

   SQL_Debug : Debugging_Support.Handle := null;

   procedure Initialize( debug : in Debugging_Support.Handle := null ) is
   begin
      SQL_Debug := debug;
   end Initialize;

   ---=====================================================================---
   ---===                        M E T H O D S                          ===---
   ---=====================================================================---

   --|
   --| Build an sql select query
   --|
   function SQL_Select(
   		colum : String := "*";
		from  : String := "";
		where : String := ""  ) return String 
   is
      Result : Unbounded_String := To_Unbounded_String( "select " );
   begin
      Result := Result & colum & " from " & from;

      if where /= ""  then
         Result := Result & " where " & where ;
      end if;

      Trace( SQL_Debug, Module & ": " & To_String( Result ) );      
      return To_String(Result);

   end SQL_Select;

   --|
   --| build an sql update query
   --|
   function SQL_Update (
     		update : String := "";
   		colum  : String := "";
		where  : String := "") return String
   is
      Result : Unbounded_String := To_Unbounded_String( "update " );
   begin
      Result := Result & update & " set " & colum;

      if where /= ""  then
         Result := Result & " where " & where ;
      end if;

      Trace( SQL_Debug, Module & ": " & To_String( Result ) );      
      return TO_String(Result);

   end SQL_Update;

   --|
   --| generate sql string
   --|
   function SQL_String( str : Unbounded_String ) return String is
   begin
      return TO_String( "'" & str & "'" );
   end SQL_String;

   --|
   --|
   --|
   function SQL_Colum ( domain : String; 
                         value : Unbounded_String ) return String is
   begin
      return domain & "=" & SQL_String( value );
   end SQL_Colum;

   --|
   --|
   --|
   function SQL_Insert ( into : String;
                         value : Unbounded_String ) return String is
   begin
      Trace( SQL_Debug, Module &
              " insert into " & into & " values (" & To_String(value) & ")");
	      
      return "insert into " & into & " values (" & To_String(value) & ")"; 
   end SQL_insert;

   --|
   --|
   --|
   function SQL_Delete( from : String;
   			where : Unbounded_String ) return String is
   begin
      Trace( SQL_Debug,	 Module & 
      	      " delete from " & from & " where " & TO_String( where ));

      return  "delete from " & from & " where " & TO_String( where );
   end SQL_Delete;


end DBS.SQL;

