--|
--| Filename        : $Source: /home/ACDE/ACDE/Source/RCS/html.adb,v $
--| Description     : HTML helper package
--| Author          : Michael Erdmann
--| Created On      : 25.3.1999
--| Last Modified By: $Author: ACDE $
--| Last Modified On: $Date: 2000/01/21 17:18:23 $
--| Status          : $State: Released $
--| Version         : $Revision: 1.1 $
--|
--| Functional Description
--| ======================
--| This package is a collection of procedure and functions
--| in order to support the generation of HTML pages 
--| by an CGI application.
--| It does not contain any Header function, because this 
--| is handled within the CGI package.
--|
--| Restrictions
--| ============
--| none
--|
--| References
--| ==========
--| none
--|
--| History
--| =======
--| $Log: html.adb,v $
--| Revision 1.1  2000/01/21 17:18:23  ACDE
--| Release Version test_1_0
--|
--| Revision 1.7  2000/01/08 09:16:53  ACDE
--| ASCL debug feature added
--|
--| Revision 1.6  1999/12/18 13:29:00  ACDE
--| Release Version V6test
--|
--| Revision 1.1  1999/12/05 19:05:34  ACDE
--| No comments
--|

--* Ada

with Ada.Text_IO;    use Ada.Text_IO;

with ASCL.Debugging_Support;   use ASCL.Debugging_Support;
use  ASCL;

package body Html is

   Version : constant String := "$Id: html.adb,v 1.1 2000/01/21 17:18:23 ACDE Released ACDE $";
   Module  : constant String := "html.adb";

   ---======================================================================---
   ---===                   C L A S S   M E T H O D S 		       	 ===---
   ---======================================================================---
   HTML_Debug : Debugging_Support.Handle := null;
   
   procedure Initialize( debug  : in Debugging_Support.Handle := null ) is
   begin
      Enter( debug, Module & ".Initialize" );

      HTML_Debug := debug;
         
      Leave( debug, "");
   end Initialize;

   --|
   --| Output a HTML command to the output file and 
   procedure HTML_Output( s : in String := "" ) is
   begin
      Trace( HTML_Debug, "HTML: " & s );
      Put_Line(s);
   end HTML_Output;

   ---=====================================================================---
   ---===                    M E T H O D S 				===---
   ---=====================================================================---
   function HTML_String( s : in String ) return String is
   begin
      return '"' & s & '"';
   end HTML_String;

   procedure Form( action : in String ) is
   begin
      HTML_Output( "<FORM METHOD=POST ACTION=" & HTML_String(action) & ">" );
   end Form;

   procedure Form_End is
   begin
      HTML_Output( "</FORM>");
   end Form_End;


   procedure Check_Box( name : in String; checked : in Boolean := False) is
   begin
      HTML_Output("<INPUT NAME=" & HTML_String(name) & " TYPE=CHECKBOX>");
   end Check_Box;

   procedure Radio_Button( name : in String; value : in String := "" ) is
   begin
      HTML_Output("<INPUT NAME=" & HTML_String(name) & 
                     " TYPE=RADIO" & 
                     " VALUE=" & HTML_String(value) & ">" ); 
   end Radio_Button;

   procedure Text( name  : in String; 
                   value : in String := "";
                   size  : in Integer := 0 ) is
   begin
      HTML_Output("<INPUT NAME=" & HTML_String( name ) & " TYPE=TEXT" );
      if size > 0  then
         HTML_Output( " SIZE=" & Integer'Image(size) );
      end if;
      HTML_Output( " VALUE=" & HTML_String(value)  & ">");
   end Text;

   procedure Submit( value : in String; name : in String := "" ) is
   begin
      HTML_Output("<INPUT TYPE=SUBMIT VALUE=" & HTML_String(value) &
                      " NAME=" & HTML_String( name ) &  ">" );
   end Submit;

   procedure Reset( text : in String ) is
   begin
      HTML_Output("<INPUT TYPE=RESET VALUE=" & HTML_String(text) & ">" );
   end Reset;

   procedure Line is
   begin
      HTML_Output("<HR>");
   end Line;

   procedure Selection( Name  : in String; 
                        Size  : in Positive := 1;
			Width : in Positive := 60 ) is
   begin
      HTML_Output("<SELECT SIZE=" & Positive'Image(Size) & 
                      " WIDTH=" & Positive'Image(Width) & "%" &
                      " NAME=" & name &
		      " >");
   end Selection;

   procedure Selection_End is
   begin
      HTML_Output("</SELECTION>");
   end Selection_End;

   procedure Option( text     : in String;
                     value    : in String; 
                     selected : in Boolean := False;
		     disabled : in Boolean := False ) is
   begin
      HTML_Output("<OPTION VALUE=" & value );
      if disabled then
         HTML_Output(" DISABLED ");
      end if;
      if selected then
         HTML_Output(" SELECTED ");
      end if;
      HTML_Output(">");
      HTML_Output( text );

   end Option;

   procedure Heading( level : in Positive; text : in String ) is
      function Trim( s : String ) return String is
      begin
         return s(2..s'Length);
      end Trim;
   begin
      HTML_Output( "<H" & Trim(Positive'Image(level)) & ">" &
                       text & 
	        "</H" & Trim(Positive'Image(level)) & ">");
   end Heading;

   procedure Break( text : in String := "" ) is
   begin
      HTML_Output( text & "<BR>");
   end Break;

   procedure Tag( label : in String; text : in String := "" ) is
   begin
      HTML_Output( "<A NAME=" & HTML_String(label) & ">" & Text & "</A>" );
   end Tag;

   procedure Link( tag : in String; text : String := "" ) is
   begin
      HTML_Output("<A HREF=" & HTML_String(tag) & ">" & text & "</A>" );
   end Link;

   procedure Table( aux : in String := "" ) is
   begin
      HTML_Output("<TABLE " & aux & ">");
   end Table;

   procedure Table_End is
   begin
      HTML_Output("</TABLE>");
   end Table_End;

   procedure TR( aux : in String :="" ) is
   begin
      HTML_Output("<TR " & aux & ">" );
   end TR;

   procedure TR_End is
   begin
      HTML_Output("</TR>");
   end TR_End;

   procedure TD( aux : in String := "" ) is
   begin
      HTML_Output("<TD" & aux & ">" );
   end TD;

   procedure TD_End is
   begin
      HTML_Output("</TD>");
   end TD_End;


   procedure Print( s : in String ) is
   begin
      HTML_Output(s);
   end Print;

end Html;




