--|  
--| Filename        : $Source: /home/ACDE/ACDE/Source/RCS/interface-command.ads,v $
--| Description     : Command interface
--| Author          : Michael Erdmann
--| Created On      : 14.1.2000
--| Last Modified By: $Author: ACDE $
--| Last Modified On: $Date: 2000/01/21 17:18:23 $
--| Status          : $State: Released $
--| Version         : $Revision: 1.1 $
--|
--| Functional Description
--| ======================
--| This is the basic interface for a command. A command is class
--| which is used by the restricted object class to execute actions
--| upon instances of the restricted object class.
--|
--| Arguments of such commands are expected to be attributes
--| of the object it self.
--|
--| During initialization of the package properties per role may
--| be set by the implementation of the abstract class.
--|
--| Component Data
--| ==============
--| Id  - Name of the command class
--|
--| Class Data
--| ==========
--|
--|
--| Operations on the component data
--| ================================
--| 1.) Attribute functions as required by coding rules and the
--|     interface defined in this package.
--| 2.) Additional attributes defined in the extension, i.e.
--|     command arguments.
--|
--| Extension
--| =========
--| This is an interface class, which means all methods defined in this
--| package are abstract.
--|
--| Restrictions
--| ============
--| None
--|
--| History
--| =======
--| $Log: interface-command.ads,v $
--| Revision 1.1  2000/01/21 17:18:23  ACDE
--| Release Version test_1_0
--|
--| Revision 1.1  2000/01/15 08:29:55  ACDE
--| No comments
--|
with ASCL.Debugging_Support;
use  ASCL;

with Interface.Role;                    use Interface.Role;

package Interface.Command is
   ---=====================================================================---
   ---===             C O M P O N E N T   I N T E R F A C E             ===---
   ---=====================================================================---
   type Object is abstract tagged private;
   type Handle is access Object'Class;

   procedure Initialize( this  : in out Object'Class;
                         debug : in Debugging_Support.Handle := null);

   procedure Finalize( this : in out Object'Class );

   ---=====================================================================---
   ---===            E X P O R T E D    D A T A   T Y P E S		===---
   ---=====================================================================---
   subtype External_ID is String;

   ---=====================================================================---
   ---===                   E X T E N S I O N                           ===---
   ---=====================================================================---

   ---=====================================================================---
   ---===                  A T T R I B U T E S                          ===---
   ---=====================================================================---
   function  Id( this : in Object ) return External_ID is abstract;

   ---=====================================================================---
   ---===                     M E T H O D S                             ===---
   ---=====================================================================---

   ---------------------------------------------------------------------------
   --| Description    :
   --|    This is a command handler, which means the action defined by
   --|    an implementation of this class is performed within this 
   --|    procedure.
   --| Preconditions  :
   --| Postconditions :
   --| Exceptions     :
   --| Note           :
   ---------------------------------------------------------------------------
   procedure Handler( this : in out Object ) is abstract;

   ---=====================================================================---
private
   type Object_Data;
   type Object_Data_Access is access Object_Data;

   type Object is  abstract tagged record
         data : Object_Data_Access := null;
      end record; 

end Interface.Command;


