--|  
--| Filename        : $Source: /home/ACDE/ACDE/Source/RCS/list.ads,v $
--| Description     : List
--| Author          : Michael Erdmann
--| Created On      : 25.3.1999
--| Last Modified By: $Author: ACDE $
--| Last Modified On: $Date: 2000/01/21 17:18:23 $
--| Status          : $State: Released $
--| Version         : $Revision: 1.1 $
--|
--|
--| Functional Description
--| ======================
--| This package defines the behavior of a linked list.
--|
--| Component Data
--| ==============
--| Last  - Last Element in list
--| First - First List Element
--|
--|
--|
--| Operations on the component data
--| ================================
--| Append - append to the end of the list
--|
--| Extension
--| =========
--|
--| Restrictions
--| ============
--| Tasking: yes/no
--| Y2K    :
--|
--| History
--| =======
--| $Log: list.ads,v $
--| Revision 1.1  2000/01/21 17:18:23  ACDE
--| Release Version test_1_0
--|
--| Revision 1.4  1999/12/28 17:42:31  ACDE
--| Get Interface added
--|
--| Revision 1.3  1999/12/26 10:13:27  ACDE
--| first tests with xref.ads, xref.adb passed
--|
--| Revision 1.2  1999/12/25 09:04:28  ACDE
--| No comments
--|
--| Revision 1.1  1999/12/21 20:02:57  ACDE
--| No comments
--|
--|
with ASCL.Debugging_Support;
use  ASCL;

with Interface.List_Element;
use  Interface;

package List is
   
   ---=====================================================================---
   ---===             C O M P O N E N T   I N T E R F A C E             ===---
   ---=====================================================================---
   type Object is tagged private;
   type Handle is access Object'Class;

   procedure Initialize( this  : in out Object'Class;
                         debug : in Debugging_Support.Handle := null);

   procedure Finalize( this : in out Object'Class );

   ---=====================================================================---
   ---===                  A T T R I B U T E S                       ===---
   ---=====================================================================---
   
   function First( this : in Object'Class ) return List_Element.Handle;
   function Last( this : in Object'Class )  return List_Element.Handle;

   ---=====================================================================---
   ---===                     M E T H O D S                             ===---
   ---=====================================================================---

   ---------------------------------------------------------------------------
   --| Description    :
   --| Preconditions  :
   --| Postconditions :
   --| Exceptions     :
   --| Note           :
   ---------------------------------------------------------------------------
   procedure Append(  this : in out Object'Class; 
                      item : in List_Element.Object'Class);

   ---------------------------------------------------------------------------
   --| Description    :
   --| Preconditions  :
   --| Postconditions :
   --| Exceptions     :
   --| Note           :
   ---------------------------------------------------------------------------

   Success : exception;
   Failure : exception;

   generic
      type Iterator_Type is private;
      with procedure Process( 
	             cntx : in out Iterator_Type; 
	             item : in out List_Element.Object'Class);

   procedure Perform( this : in out Object'Class;
   		      cntx : in out Iterator_Type );


   type Get_Mode is ( First, Next );
   function Get( this : in Object'Class; mode : Get_Mode := Next )
   		return List_Element.Handle; 

   ---=====================================================================---
   ---===                   E X T E N S I O N                           ===---
   ---=====================================================================---

   ---=====================================================================---
private
   type Object_Data;
   type Object_Data_Access is access Object_Data;

   type Object is tagged record
         data : Object_Data_Access := null;
      end record; 

end List;


