--|
--| Filename        : $Source: /home/ACDE/ACDE/Source/RCS/parser.ads,v $
--| Description     : Ada Parser
--| Author          : Michael Erdmann
--| Created On      : 26.12.1999
--| Last Modified By: $Author: ACDE $
--| Last Modified On: $Date: 2000/01/21 17:18:23 $
--| Status          : $State: Released $
--| Version         : $Revision: 1.1 $
--|
--|
--| Functional Description
--| ======================
--| This package supplies an ada parser which call interface
--| procedures which may be used to build a seamntic tree. 
--|
--| Component Data
--| ==============
--| None
--|
--|
--| Operations on the component data
--| ================================
--|
--| Extension
--| =========
--|
--| Restrictions
--| ============
--|
--| History
--| =======
--| $Log: parser.ads,v $
--| Revision 1.1  2000/01/21 17:18:23  ACDE
--| Release Version test_1_0
--|
--| Revision 1.2  2000/01/16 16:06:17  ACDE
--| Release Version V8_1test
--|
--| Revision 1.1  1999/12/30 09:11:37  ACDE
--| first tests for docgen complete
--|
--|
--| 
with ASCL.Debugging_Support;
use  ASCL;

with List;

package Parser is

   ---=====================================================================---
   ---===             C O M P O N E N T   I N T E R F A C E             ===---
   ---=====================================================================---
   type Object is tagged private;
   type Handle is access Object'Class;

   ---------------------------------------------------------------------------
   --| Description    :
   --|   Intialize the parser instance. The debug handle may be
   --|   set by be caller.
   --|   The Initialize call does not start the parsing of a given
   --|   file.
   --| 
   --| Preconditions  :
   --|   1. Object not initialized
   --|
   --| Postconditions :
   --| Exceptions     :
   --| Note           :
   ---------------------------------------------------------------------------
   procedure Initialize( This  : in out Object'Class; 
                         debug : in Debugging_Support.Handle := null );
		  
   ---------------------------------------------------------------------------
   --| Description    :
   --|    Finalize the parser object. This means the input file
   --|    is closed if open and the object data is given back
   --|    to the system.
   --|
   --| Preconditions  :
   --|    1. Instance is initialized.
   --|
   --| Postconditions :
   --| Exceptions     :
   --| Note           :
   ---------------------------------------------------------------------------
   procedure Finalize( This : in out Object'Class );

   ---=====================================================================---
   ---===                  A T T R I B U T E S                       ===---
   ---=====================================================================---
      
   ---------------------------------------------------------------------------
   --| Description    :
   --|    Get the result list of all previous parsing steps.
   --| Preconditions  :
   --|    Object has to be initialized
   --|    Parser should be executed before.
   --| Postconditions :
   --| Exceptions     :
   --| Note           :
   ---------------------------------------------------------------------------
   function Result( O : in Object'Class) return List.Object;

   ---=====================================================================---
   ---===                     M E T H O D S                             ===---
   ---=====================================================================---

   ---------------------------------------------------------------------------
   --| Description    :
   --|    This procedure starts the parsing of a component given as
   --|    the second argument. During this process a list of contents
   --|    elements is generated.
   --| Preconditions  :
   --|    1. Object has to be initialized.
   --| Postconditions :
   --|    The component has a stored result which might be accessed via
   --|    the result procedure.
   --| Exceptions     :
   --|    Any
   --| Note           :
   ---------------------------------------------------------------------------
   procedure Parse( O : in out Object'Class;  Ada_Source : in String );
	 
   ---=====================================================================---
private
   type Object_Data;
   type Object_Data_Access is access Object_Data;
   function Initialize return Object_Data_Access;

   type Object is tagged record 
         Data :  Object_Data_Access := Initialize;
      end record;

end Parser;
