--|  
--| Filename        : $Source: /home/ACDE/ACDE/Source/RCS/restricted.ads,v $
--| Description     : Restricted Objects
--| Author          : Michael Erdmann
--| Created On      : 15.1.2000
--| Last Modified By: $Author: ACDE $
--| Last Modified On: $Date: 2000/01/21 17:18:23 $
--| Status          : $State: Released $
--| Version         : $Revision: 1.1 $
--|
--|
--| Functional Description
--| ======================
--| This class is intended for extension. It defines the data and methods
--| of an object where the object is restricted. 
--| Before a command is executed (see interface.commnand) checks are 
--| performed it the command is allowed to be executed in the 
--| context of the current role. 
--|
--|
--| Component Data
--| ==============
--| Role      - This is the current role of the object
--|
--|
--| Operations on the component data
--| ================================
--| Role       - Set/get the current role.
--|
--| Methods
--| =======
--|
--| Authorize  - Authorize a certain command for a role
--| Execute    - Execute a command in the context of the 
--|              current role.
--|
--| Extension
--| =========
--| non extension is required by this interface.
--|
--| Restrictions
--| ============
--| none
--|
--| History
--| =======
--| $Log: restricted.ads,v $
--| Revision 1.1  2000/01/21 17:18:23  ACDE
--| Release Version test_1_0
--|
--| Revision 1.3  2000/01/15 18:26:24  ACDE
--| No comments
--|
--|

--* ASCL components
with ASCL.Debugging_Support;
use  ASCL;

--* Common Interfaces
with Interface.Command;
with Interface.Role;             use Interface.Role;
use  Interface;

package Restricted is
   
   ---=====================================================================---
   ---===             C O M P O N E N T   I N T E R F A C E             ===---
   ---=====================================================================---
   type Object is abstract tagged private;
   type Handle is access Object'Class;

   procedure Initialize( this  : in out Object'Class;
                         debug : in Debugging_Support.Handle := null);

   procedure Finalize( this : in out Object'Class );

   ---=====================================================================---
   ---===       E X P O R T E D    I T E M S / D A T A T Y P E S	===---
   ---=====================================================================---
   Not_Authorized : exception;
   Not_Owner      : exception;

   ---=====================================================================---
   ---===                  A T T R I B U T E S                       ===---
   ---=====================================================================---

   procedure Role( this : in out Object'Class; role : in Role_Identifier );
   function  Role( this  : in Object'Class) return Role_Identifier;

   ---=====================================================================---
   ---===                     M E T H O D S                             ===---
   ---=====================================================================---

   ---------------------------------------------------------------------------
   --| Description    :
   --|    Execute the given command in the context of the current 
   --|    role.
   --|	
   --| Preconditions  :
   --|    P1 - Object has to be initialized
   --|    P2 - Current role has been set.
   --|
   --| Postconditions :
   --|    Command my have changed the contents of the restricted
   --|    object.
   --| Exceptions     :
   --|    Not_Authorized  - The command was not authorized for this 
   --|                      object.
   --| Note           :
   ---------------------------------------------------------------------------
   procedure Execute( this : in Object'Class; 
                      cmd  : in out Command.Object'Class );

   ---------------------------------------------------------------------------
   --| Description    :
   --|    Authorize the given command instance for the given role. 
   --| Preconditions  :
   --|    P1 - Object has to be initialized
   --|    P2 - At least the user or the group has to be set
   --| Postconditions :
   --|    None
   --| Exceptions     :
   --|    Any
   --| Note           :
   ---------------------------------------------------------------------------
   procedure Authorize( this  : in out Object'Class; 	
   			cmd   : in Command.External_ID;
                        where : in Role_Identifier );

   ---=====================================================================---
   ---===                   E X T E N S I O N                           ===---
   ---=====================================================================---

   ---=====================================================================---
private
   type Object_Data;
   type Object_Data_Access is access Object_Data;

   type Object is  abstract tagged record
         data : Object_Data_Access := null;
      end record; 

end Restricted;


