--|
--| Filename        : $Source: /home/ACDE/ACDE/Source/RCS/std-cgi_debug.adb,v $
--| Description     : Debugging output
--| Author          : Michael Erdmann
--| Created On      : 25.3.1999
--| Last Modified By: $Author: ACDE $
--| Last Modified On: $Date: 2000/01/21 17:18:23 $
--| Status          : $State: Released $
--| Version         : $Revision: 1.2 $
--|
--| Functional Description
--| ======================
--| This is the implementation for the ASCL debug class in the CGI/HTML
--| environment. Every information is stored until the dump command
--| is issued by an application.
--|
--| Restrictions
--| ============
--|
--| References
--| ==========
--|
--|
--| History
--| =======
--| $Log: std-cgi_debug.adb,v $
--| Revision 1.2  2000/01/21 17:18:23  ACDE
--| Release Version test_1_0
--|
--| Revision 1.1  2000/01/20 20:56:34  ACDE
--| No comments
--|
--|

--* Ada

with Ada.Text_IO;    use Ada.Text_IO;  
use  Ada;

with ASCL.Debugging_Support;
with CGI;
use  ASCL;

package body STD.CGI_Debug is

   type Output_List_Element;
   type Output_List_Element_Access is access Output_List_Element;

   type Output_List_Element( size : Positive ) is record
         Next : Output_List_Element_Access := null;
         Info : String( 1..size );
      end record;
   	
   type Object_Data is record
	 Head : Output_List_Element_Access := null;
	 Tail : Output_List_Element_Access := null;
      end record;

   --|
   --| Initialize the class data
   --|
   procedure Initialize( this : in out Object ) is
   begin
      this.Data := new Object_Data;
   end Initialize;

   --|
   --| Finalize. Most of the tasks are left out, because the 
   --| process is assuemd to terminate ater finalize is executed.
   --|
   procedure Finalize( this : in out Object ) is
   begin
      null;
   end Finalize;


   --|
   --| Implementation of the output procedure. It recevies text
   --| which is stored in a linked list.
   --|
   procedure Output( this : in out Object;  text : in String ) is
      Data    : Object_Data_Access renames this.data;
      Element : Output_List_Element_Access;
   begin
      if Data = null then
         return;
      end if;

      Element := new Output_List_Element( text'Length );
      Element.Info := text;

      if Data.Tail = null then
         Data.Head := Element;
      else
         Data.Tail.Next := Element;
      end if;
      Data.Tail := Element;
   end Output;

   --|
   --| This procedure is not part of the regular debug interface. It 
   --| is used by the application to print the trace information
   --| in html formatting compatible way.
   --|
   procedure Dump( this : in out Object; file : in File_Type ) is
      Data     : Object_Data_Access renames this.data;
      Current  : Output_List_Element_Access;
   begin
      if Data = null then
         return;
      end if;

      Put_Line(File,"<HR><B>Input Data</B><BR>");               
      CGI.Put_Variables;

      Put_Line(File, "<HR><B>Internal Trace</B><BR><BR>");
      Current := Data.Head;
      while Current /= null loop
         Put_Line( File, Current.Info & "<BR>" );

         Current := Current.Next;
	 Data.Head := Current;
      end loop;
      Put_Line(File,"<BR>");

   end Dump;

end  STD.CGI_Debug; 
