--|  
--| Filename        : $Source: /home/ACDE/ACDE/Source/RCS/text_block.ads,v $
--| Description     : Store a block of text
--| Author          : Michael Erdmann
--| Created On      : 25.3.1999
--| Last Modified By: $Author: ACDE $
--| Last Modified On: $Date: 2000/01/21 17:18:23 $
--| Status          : $State: Released $
--| Version         : $Revision: 1.1 $
--|
--|
--| Functional Description
--| ======================
--| This package implements operations on test blocks. A text
--| block is a collection of unbounded strings.
--|
--| Component Data
--| ==============
--|
--| Text   - Return a text block.
--| Length - Number of lines in the text block.
--|
--| Operations on the component data
--| ================================
--|
--| Add   - Add a text line to the text block.
--|
--| Extension
--| =========
--| None
--|
--| Restrictions
--| ============
--| Tasking: no
--| Y2K    : yes
--|
--| History
--| =======
--| $Log: text_block.ads,v $
--| Revision 1.1  2000/01/21 17:18:23  ACDE
--| Release Version test_1_0
--|
with Ada.Strings.Unbounded;		use Ada.Strings.Unbounded;

with ASCL.Debugging_Support;
use  ASCL;

package Text_Block is
   
   ---=====================================================================---
   ---===             C O M P O N E N T   I N T E R F A C E             ===---
   ---=====================================================================---
   type Object is tagged private;
   type Handle is access Object'Class;

   procedure Initialize( this  : in out Object'Class;
                         debug : in Debugging_Support.Handle := null);

   procedure Finalize( this : in out Object'Class );

   ---=====================================================================---
   ---===                  A T T R I B U T E S                       ===---
   ---=====================================================================---
   function Length( this : in Object'Class ) return Integer;
   
   type Text_Array is array( Positive range <> ) of Unbounded_String;   
   type Text_Array_Access is access Text_Array;

   function Text( this : in Object'Class ) return Text_Array_Access;

   ---=====================================================================---
   ---===                     M E T H O D S                             ===---
   ---=====================================================================---

   ---------------------------------------------------------------------------
   --| Description    :
   --|   Add a string to the text block.
   --| Preconditions  :
   --|   Text block component has been initialized.
   --| Postconditions :
   --|   Length of the text block is updated.
   --| Exceptions     :
   --|   all
   --| Note           :
   ---------------------------------------------------------------------------
   procedure Add( this : in out Object'Class; text : in String );

   ---=====================================================================---
   ---===                   E X T E N S I O N                           ===---
   ---=====================================================================---

   ---=====================================================================---
private
   type Object_Data;
   type Object_Data_Access is access Object_Data;

   type Object is tagged record
         data : Object_Data_Access := null;
      end record; 

end Text_Block;


